@@ -2,23 +2,20 @@ from django import forms
 from django.contrib import admin
 from django.contrib.auth import get_user_model
 from django.contrib.staticfiles.templatetags.staticfiles import static
-from django.core.urlresolvers import reverse
+from django.db.models import F
 from django.shortcuts import render
+from django.urls import reverse
 from django.utils.html import format_html
 from django.utils.translation import ugettext_lazy as _
 
 from ..forms.courses import CourseDiscountAdminForm
 from ..models.courses import (
-    Course, CourseRegistration, CourseRegistrationHistory, CourseTime,
+    Course, CourseDiscount, CourseRegistration, CourseRegistrationHistory,
+    CourseTime,
 )
 from ..models.schoolyear import SchoolYear
 from ..models.subjects import SubjectType
 from ..utils import currency
-from .filters import (
-    ApprovedListFilter, CanceledListFilter, CourseGroupListFilter,
-    CourseListFilter, CourseTypeListFilter, LeaderListFilter,
-    SchoolYearListFilter,
-)
 from .pdf import PdfExportAdminMixin
 from .subjects import (
     SubjectBaseAdmin, SubjectPaymentBaseAdmin, SubjectRegistrationBaseAdmin,
@@ -30,26 +27,29 @@ class CourseTimeInlineAdmin(admin.TabularInline):
     extra = 0
 
 
+@admin.register(Course)
 class CourseAdmin(SubjectBaseAdmin):
-    subject_type = SubjectType.COURSE
+    subject_type_type = SubjectType.COURSE
     registration_model = CourseRegistration
-    list_export     = (
-        'id', 'code', 'name', 'department', 'subject_type', 'get_groups_list', 'get_leaders_list',
+    list_display = (
+        'id', 'code', 'name', 'subject_type', 'get_groups_list', 'get_leaders_list',
         'get_times_list',
-        'place', 'public',
+        'place', 'public', 'registration_allowed_icon',
+        'get_registrations_link',
+        'get_journal_link', 'icon', 'note',
+    )
+    list_export = (
+        'id', 'school_year', 'code', 'name', 'department', 'subject_type', 'registration_type',
+        'get_groups_list', 'get_leaders_list', 'get_age_groups_list', 'get_target_groups_list',
+        'get_times_list', 'place', 'public', 'price',
+        'min_participants_count', 'max_participants_count', 'min_group_members_count', 'max_group_members_count',
+        'min_registrations_count', 'max_registrations_count',
         'get_approved_registrations_count', 'get_unapproved_registrations_count', 'note',
     )
-    list_filter     = (
-        ('school_year',     SchoolYearListFilter),
-        'department',
-        ('subject_type',    CourseTypeListFilter),
-        ('groups',          CourseGroupListFilter),
-        ('leaders',         LeaderListFilter),
-    )
-    inlines         = (
+    inlines = (
         CourseTimeInlineAdmin,
     ) + SubjectBaseAdmin.inlines
-    actions         = (
+    actions = (
         'publish', 'unpublish',
         'copy_to_school_year',
     )
@@ -60,7 +60,7 @@ class CourseAdmin(SubjectBaseAdmin):
     def get_form(self, request, obj=None, **kwargs):
         form = super(CourseAdmin, self).get_form(request, obj, **kwargs)
         # school year division choices
-        if not obj or not obj.has_discounts:
+        if 'school_year_division' in form.base_fields and (not obj or not obj.has_discounts):
             # school year division can not be changed if there are discounts
             # because discounts are related to school year periods
             if obj:
@@ -75,12 +75,12 @@ class CourseAdmin(SubjectBaseAdmin):
         return form
 
     def publish(self, request, queryset):
-        Course.objects.filter(id__in=[reg['id'] for reg in queryset.values('id')]).update(public = True)
+        Course.objects.filter(id__in=[reg['id'] for reg in queryset.values('id')]).update(public=True)
         self.message_user(request, _('Selected courses were published.'))
     publish.short_description = _('Publish selected courses')
 
     def unpublish(self, request, queryset):
-        Course.objects.filter(id__in=[reg['id'] for reg in queryset.values('id')]).update(public = False)
+        Course.objects.filter(id__in=[reg['id'] for reg in queryset.values('id')]).update(public=False)
         self.message_user(request, _('Selected courses were unpublished.'))
     unpublish.short_description = _('Unpublish selected courses')
 
@@ -117,7 +117,7 @@ class CourseAdmin(SubjectBaseAdmin):
 
     def get_message_recipients(self, request, queryset):
         return get_user_model().objects.filter(
-            leprikon_registrations__subject__in = queryset
+            leprikon_registrations__subject__in=queryset,
         ).distinct()
 
 
@@ -133,39 +133,54 @@ class CourseRegistrationHistoryInlineAdmin(admin.TabularInline):
         return False
 
 
+@admin.register(CourseRegistration)
 class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin):
-    list_display    = (
-        'variable_symbol', 'download_tag', 'subject_name', 'participant', 'price',
-        'payments_partial_balance', 'payments_total_balance', 'course_discounts', 'course_payments',
-        'created', 'approved', 'payment_requested', 'cancel_request', 'canceled', 'note',
+    subject_type_type = SubjectType.COURSE
+    actions = ('add_full_discount_for_period',)
+    inlines = SubjectRegistrationBaseAdmin.inlines + (CourseRegistrationHistoryInlineAdmin,)
+    list_display = (
+        'variable_symbol', 'download_tag', 'subject_name', 'participants_list_html', 'price',
+        'course_discounts', 'course_payments',
+        'created', 'approved', 'payment_requested', 'cancel_request', 'canceled', 'note', 'random_number',
     )
-    list_filter     = (
-        ('subject__school_year',    SchoolYearListFilter),
-        'subject__department',
-        ('subject__subject_type',   CourseTypeListFilter),
-        ApprovedListFilter,
-        CanceledListFilter,
-        ('subject',                 CourseListFilter),
-        ('subject__leaders',        LeaderListFilter),
-    )
-    inlines         = (CourseRegistrationHistoryInlineAdmin,)
+
+    def add_full_discount_for_period(self, request, queryset):
+        current_period = {
+            school_year_division.id: school_year_division.get_current_period()
+            for school_year_division in request.school_year.divisions.all()
+        }
+        CourseDiscount.objects.bulk_create(
+            CourseDiscount(
+                registration_id=registration.id,
+                period=current_period[registration.subject.course.school_year_division_id],
+                amount=registration.price,
+                explanation=_('full discount for current period'),
+            )
+            for registration in queryset.annotate(
+                school_year_division_id=F('subject__course__school_year_division_id'),
+            )
+        )
+        self.message_user(request, _(
+            'The discounts have been created for each selected registration and current period.'
+        ))
+    add_full_discount_for_period.short_description = _('Add full discount for current period')
 
     def course_discounts(self, obj):
         html = []
-        for period in obj.get_period_payment_statuses():
+        for period in obj.period_payment_statuses:
             html.append(format_html(
                 '{period}: <a href="{href}"><b>{amount}</b></a>',
-                period  = period.period.name,
-                href    = (reverse('admin:leprikon_coursediscount_changelist') +
-                           '?registration={}&period={}'.format(obj.id, period.period.id)),
-                amount  = currency(period.status.discount),
+                period=period.period.name,
+                href=(reverse('admin:leprikon_coursediscount_changelist') +
+                      '?registration={}&period={}'.format(obj.id, period.period.id)),
+                amount=currency(period.status.discount),
             ))
         html.append(format_html(
             '<a class="popup-link" href="{href}" style="background-position: 0 0" title="{title}">'
             '<img src="{icon}" alt="+"/></a>',
-            href    = reverse('admin:leprikon_coursediscount_add') + '?registration={}'.format(obj.id),
-            title   = _('add discount'),
-            icon    = static('admin/img/icon-addlink.svg'),
+            href=reverse('admin:leprikon_coursediscount_add') + '?registration={}'.format(obj.id),
+            title=_('add discount'),
+            icon=static('admin/img/icon-addlink.svg'),
         ))
         return '<br/>'.join(html)
     course_discounts.allow_tags = True
@@ -173,59 +188,31 @@ class CourseRegistrationAdmin(PdfExportAdminMixin, SubjectRegistrationBaseAdmin)
 
     def course_payments(self, obj):
         html = []
-        for period in obj.get_period_payment_statuses():
+        for period in obj.period_payment_statuses:
             html.append(format_html(
                 '{period}: <a class="popup-link" style="color: {color}" href="{href}" title="{title}">'
                 '<b>{amount}</b></a>',
-                period  = period.period.name,
-                color   = period.status.color,
-                href    = reverse('admin:leprikon_subjectpayment_changelist') + '?registration={}'.format(obj.id),
-                title   = period.status.title,
-                amount  = currency(period.status.paid),
+                period=period.period.name,
+                color=period.status.color,
+                href=reverse('admin:leprikon_subjectpayment_changelist') + '?registration={}'.format(obj.id),
+                title=period.status.title,
+                amount=currency(period.status.paid),
             ))
         html.append(format_html(
             '<a class="popup-link" href="{href}" style="background-position: 0 0" title="{title}">'
             '<img src="{icon}" alt="+"/></a>',
-            href    = reverse('admin:leprikon_subjectpayment_add') + '?registration={}'.format(obj.id),
-            title   = _('add payment'),
-            icon    = static('admin/img/icon-addlink.svg'),
+            href=reverse('admin:leprikon_subjectpayment_add') + '?registration={}'.format(obj.id),
+            title=_('add payment'),
+            icon=static('admin/img/icon-addlink.svg'),
         ))
         return '<br/>'.join(html)
     course_payments.allow_tags = True
     course_payments.short_description = _('course payments')
 
-    def payments_partial_balance(self, obj):
-        return obj.get_payment_statuses().partial.balance
-    payments_partial_balance.short_description = _('actual balance')
-
-    def payments_total_balance(self, obj):
-        return obj.get_payment_statuses().total.balance
-    payments_total_balance.short_description = _('total balance')
-
-    def payments_partial_balance(self, obj):
-        status = obj.get_payment_statuses().partial
-        return '<strong title="{title}" style="color: {color}">{balance}</strong>'.format(
-            color   = status.color,
-            balance = currency(status.balance),
-            title   = status.title,
-        )
-    payments_partial_balance.allow_tags = True
-    payments_partial_balance.short_description = _('actual balance')
-
-    def payments_total_balance(self, obj):
-        status = obj.get_payment_statuses().total
-        return '<strong title="{title}" style="color: {color}">{balance}</strong>'.format(
-            color   = status.color,
-            balance = currency(status.balance),
-            title   = status.title,
-        )
-    payments_total_balance.allow_tags = True
-    payments_total_balance.short_description = _('total balance')
-
-
 
+@admin.register(CourseDiscount)
 class CourseDiscountAdmin(PdfExportAdminMixin, SubjectPaymentBaseAdmin):
-    form            = CourseDiscountAdminForm
-    list_display    = ('accounted', 'registration', 'subject', 'period', 'amount_html', 'explanation')
-    list_export     = ('accounted', 'registration', 'subject', 'period', 'amount', 'explanation')
-    closed_fields   = ('accounted', 'registration', 'period', 'amount')
+    form = CourseDiscountAdminForm
+    list_display = ('accounted', 'registration', 'subject', 'period', 'amount_html', 'explanation')
+    list_export = ('accounted', 'registration', 'subject', 'period', 'amount', 'explanation')
+    closed_fields = ('accounted', 'registration', 'period', 'amount')
