@@ -2,19 +2,23 @@ from django import forms
 from django.conf.urls import url as urls_url
 from django.contrib import admin
 from django.contrib.auth import get_user_model, login
-from django.contrib.auth.admin import UserAdmin as _UserAdmin
 from django.contrib.auth.decorators import permission_required
 from django.contrib.messages import ERROR
-from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404, render
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
+from user_unique_email.admin import UserAdmin as _UserAdmin
 
 from ..forms.user import UserAdminChangeForm, UserAdminCreateForm
 from ..utils import merge_users
 from .messages import SendMessageAdminMixin
 
+User = get_user_model()
+admin.site.unregister(User)
 
+
+@admin.register(User)
 class UserAdmin(SendMessageAdminMixin, _UserAdmin):
     actions = ('merge',)
     add_form = UserAdminCreateForm
@@ -42,7 +46,7 @@ class UserAdmin(SendMessageAdminMixin, _UserAdmin):
                         try:
                             merge_users(user, target)
                             self.message_user(request, _('User {} was merged into user {}.').format(user, target))
-                        except:
+                        except Exception:
                             self.message_user(
                                 request, _('Can not merge user {} into user {}.').format(user, target),
                                 level=ERROR
@@ -51,13 +55,13 @@ class UserAdmin(SendMessageAdminMixin, _UserAdmin):
         else:
             form = MergeForm()
         return render(request, 'leprikon/admin/merge.html', {
-            'title':    _('Select target user for merge'),
+            'title': _('Select target user for merge'),
             'question': _('Are you sure you want to merge selected users into one? '
                           'All participants, parents, registrations and other related information '
                           'will be added to the target user account and the remaining users will be deleted.'),
             'queryset': queryset,
-            'objects_title':    _('Users'),
-            'form_title':       _('Select target account for merge'),
+            'objects_title': _('Users'),
+            'form_title': _('Select target account for merge'),
             'opts': self.model._meta,
             'form': form,
             'action_checkbox_name': admin.helpers.ACTION_CHECKBOX_NAME,
@@ -94,9 +98,11 @@ class UserAdmin(SendMessageAdminMixin, _UserAdmin):
     def get_urls(self):
         urls = super(UserAdmin, self).get_urls()
         login_as_view = self.admin_site.admin_view(permission_required('auth.change_user')(self.login_as))
-        return [
-            urls_url(r'(?P<user_id>\d+)/login-as/$', login_as_view, name='auth_user_login_as'),
-        ] + urls
+        return [urls_url(
+            r'(?P<user_id>\d+)/login-as/$',
+            login_as_view,
+            name=f'{User._meta.app_label}_{User._meta.model_name}_login_as',
+        )] + urls
 
     def login_as(self, request, user_id):
         if request.user.is_superuser:
@@ -109,16 +115,16 @@ class UserAdmin(SendMessageAdminMixin, _UserAdmin):
 
     def login_as_link(self, obj):
         return '<a href="{url}">{text}</a>'.format(
-            url     = reverse('admin:auth_user_login_as', args=[obj.id]),
-            text    = _('login')
+            url=reverse(f'admin:{User._meta.app_label}_{User._meta.model_name}_login_as', args=[obj.id]),
+            text=_('login')
         ) if not obj.is_staff and not obj.is_superuser else ''
     login_as_link.allow_tags = True
     login_as_link.short_description = _('login')
 
     def login_as_link_superuser(self, obj):
         return '<a href="{url}">{text}</a>'.format(
-            url     = reverse('admin:auth_user_login_as', args=[obj.id]),
-            text    = _('login')
+            url=reverse(f'admin:{User._meta.app_label}_{User._meta.model_name}_login_as', args=[obj.id]),
+            text=_('login')
         )
     login_as_link_superuser.allow_tags = True
     login_as_link_superuser.short_description = _('login')
