@@ -8,5 +8,6 @@ def l_url(pattern, name):
 
 
 urlpatterns = [
-    l_url(r'^registrations/(?P<subject_id>[0-9]+)/$', 'registrations'),
+    l_url(r'^participants/(?P<subject_id>[0-9]+)/$', 'participants'),
+    l_url(r'^rocketchat/$', 'rocketchat'),
 ]
