@@ -21,40 +21,39 @@ class MessageFilterForm(FormMixin, forms.Form):
         qs = self.qs
         for word in self.cleaned_data['q'].split():
             qs = qs.filter(
-                Q(message__subject__icontains = word) |
-                Q(message__text__icontains = word)
+                Q(message__subject__icontains=word) |
+                Q(message__text__icontains=word)
             )
         return qs.distinct()
 
 
-
 class MessageAdminForm(forms.ModelForm):
     recipients = forms.MultipleChoiceField(
-        widget      = widgets.FilteredSelectMultiple(
-            verbose_name = _('Recipients'),
-            is_stacked = False,
+        choices=lambda: [
+            (u.id, '{} ({})'.format(u.get_username(), u.get_full_name()))
+            for u in get_user_model().objects.all()
+        ],
+        widget=widgets.FilteredSelectMultiple(
+            verbose_name=_('Recipients'),
+            is_stacked=False,
         ),
-        label       = _('Recipients'),
-        required    = False,
+        label=_('Recipients'),
+        required=False,
     )
 
     class Meta:
         model = Message
-        fields = ['subject', 'text']
+        fields = ['sender', 'subject', 'text']
 
     def __init__(self, *args, **kwargs):
         instance = kwargs.get('instance', None)
         if instance:
             kwargs['initial'] = kwargs.get('initial', {})
-            kwargs['initial']['recipients'] = set(
+            kwargs['initial']['recipients'] = list(set(
                 kwargs['initial'].get('recipients', []) +
                 [r[0] for r in instance.recipients.values_list('recipient_id')]
-            )
-        super(MessageAdminForm, self).__init__(*args, **kwargs)
-        self.fields['recipients'].choices = [
-            (u.id, '{} ({})'.format(u.get_username(), u.get_full_name()))
-            for u in get_user_model().objects.all()
-        ]
+            ))
+        super().__init__(*args, **kwargs)
 
     def _save_m2m(self):
         super(MessageAdminForm, self)._save_m2m()
@@ -63,5 +62,5 @@ class MessageAdminForm(forms.ModelForm):
             if recipient.recipient_id not in recipients:
                 recipient.delete()
         for user_id in recipients:
-            MessageRecipient.objects.get_or_create(recipient_id=user_id, message = self.instance)
+            MessageRecipient.objects.get_or_create(recipient_id=user_id, message=self.instance)
         return self.instance
