@@ -7,14 +7,15 @@ from .form import FormMixin
 class ParticipantForm(FormMixin, forms.ModelForm):
 
     def __init__(self, user, **kwargs):
-        super(ParticipantForm, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.instance.user = user
 
     class Meta:
         model = Participant
         fields = [
-            'first_name', 'last_name', 'birth_num', 'age_group',
-            'street', 'city', 'postal_code', 'citizenship',
+            'first_name', 'last_name', 'citizenship',
+            'birth_num', 'birth_date', 'gender',
+            'age_group', 'street', 'city', 'postal_code',
             'email', 'phone',
             'school', 'school_other', 'school_class',
             'health',
