@@ -2,6 +2,7 @@ from datetime import date
 
 from ..models.courses import CourseRegistration
 from ..models.events import EventRegistration
+from ..models.utils import PaymentStatusSum
 from .generic import TemplateView
 
 
@@ -12,24 +13,23 @@ class SummaryView(TemplateView):
     def get_context_data(self, **kwargs):
         context = super(SummaryView, self).get_context_data(**kwargs)
         context['user'] = self.request.user
-        context['payment_status'] = sum(
-            reg.payment_statuses.partial
+        context['payment_status_sum'] = sum(
+            sum(reg.payment_statuses)
             for reg in CourseRegistration.objects.filter(
-                subject__school_year = self.request.school_year,
-                user = self.request.user,
+                user=self.request.user,
+                approved__isnull=False,
             )
         ) + sum(
             reg.payment_status
             for reg in EventRegistration.objects.filter(
-                subject__school_year = self.request.school_year,
-                user = self.request.user,
+                user=self.request.user,
+                approved__isnull=False,
             )
-        )
+        ) + PaymentStatusSum(0, 0, 0, 0, 0, 0)
         context['new_messages'] = self.request.user.leprikon_messages.filter(viewed=None)
         return context
 
 
-
 class LeaderSummaryView(TemplateView):
     summary = True
     template_name = 'leprikon/leader_summary.html'
